@@ -20,14 +20,15 @@ class MangaLibMe(Provider, Std):
 
     def get_files(self):
         content = self.http_get(self.chapter)
-        base_url = self.re.search(r'\bimgUrl: *[\'"]([^\'"]+)', content).group(1)
-        images = self.re.search(r'\bpages: *(\[\{.+\}\])', content).group(1)
+        images = self.re.search(r'__pg\s*=\s*(\[.+\])', content).group(1)
+        info = self.re.search(r'__info\s*=\s*(\{.+\})', content).group(1)
         images = self.json.loads(images)
-        imgs = ['https://img2.mangalib.me{}{}'.format(
-            base_url,
-            i.get('page_image'),
-        ) for i in images]
-        return imgs
+        info = self.json.loads(info)
+        _manga = info['img']['url']
+        _s = info['servers']
+        _server = _s.get('main', _s.get('secondary'))
+
+        return ['{}{}{}'.format(_server, _manga, i['u']) for i in images]
 
     def get_cover(self):
         return self._cover_from_content('img.manga__cover')
