@@ -4,9 +4,6 @@ from .helpers.std import Std
 
 class ReMangaOrg(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index().split('-'))
-
     def get_chapter_index(self) -> str:
         idx = self.re.search(r'/vol(\d+)/(\d+(?:\.\d+)?)', self.chapter)
         return '{}-{}'.format(
